@@ -15,24 +15,39 @@ class API:
 
     def __init__(self, token: str):
         self.token = token
-
-    def post(self, endpoint: str, body: dict = {}):
-        """
-        Make a POST request to the API.
-
-        :param params: dictionary of custom params to add to request.
-        """
-        headers = {
+        self.headers = {
             'Authorization': 'Bearer ' + self.token,
         }
-        request = requests.post(self._HOST + self._API_ROOT + endpoint,
-                                json=body,
-                                headers=headers)
+
+    def _get(self, endpoint: str):
+        """
+        Make a GET request to the API.
+        """
+        request = requests.get(self._HOST + self._API_ROOT + endpoint,
+                                headers=self.headers)
         if request.ok:
             return request.json()
         else:
             raise Exception('API request failed. Received:\n' + request.text)
 
+    def _post(self, endpoint: str, body: dict = {}):
+        """
+        Make a POST request to the API.
+        """
+        request = requests.post(self._HOST + self._API_ROOT + endpoint,
+                                json=body,
+                                headers=self.headers)
+        if request.ok:
+            return request.json()
+        else:
+            raise Exception('API request failed. Received:\n' + request.text)
+
+    def filters(self):
+        """
+        Get a list of valid filters and recognized values.
+        """
+        return self._get('filters')
+
     def people(self, query=None, filters=None, page=None, page_size=None):
         """
         Given search criteria, get a list of matching people.
@@ -46,5 +61,5 @@ class API:
         body = {k: v for k, v in body.items() if v}
         return [
             Person(person) for person in
-            self.post('people', body=body)
+            self._post('people', body=body)
         ]
